<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>Выберите объект или регион</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>Переместить объект или привязку</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>Установите второй угол</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>Укажите целевую точку точки привязки</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>Укажите целевую точку выделения</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Переместите объект в нужное место</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Переместить точку привязки</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Перенести выделение</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Перенести объект</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Редактируя блок &apos;%1&apos;,&lt;br&gt;Выберите &lt;i&gt;Блок &gt; Возврат к главному рисованию&lt;/i&gt;, когда закончите</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Активный инструмент:</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Параметры</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translation type="vanished">Опции блока</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>Главные инструменты</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>Инструменты CAD</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>Объект находится на заблокированном слое.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Длина:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>Объект не является привязкой блока.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>Объект не является линией или дугой.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Объект не является линией, дугой или ломаной.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>Объект не является линией.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>Объект не является дугой или окружностью.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>Объект не является линией, дугой или окружностью.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>Объект не является дугой, окружностью или эллипсом.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Объект не является линией, окружностью или эллипсом.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Объект не является линией, окружностью, эллипсом или ломаной.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Объект не является кривой, дугой, окружностью, эллипсом или сплайном.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Объект не является линией, дугой, окружностью, эллипсом, кривой или ломаной.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>Объект не является ломаной.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Радиус уменьшился до 0.0 после %1 концентрической(их) окружности(ей).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Радиус уменьшился до 0.0 после %1 концентрической(их) дуг(и).</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1413"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>По крайней мере две точки идентичны.</translation>
    </message>
    <message>
        <location line="-22"/>
        <source>No circle possible.</source>
        <translation>Нет возможности для окружности.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Нет возможности для дуги.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>Неверное количество сегментов: %1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>Неверный эллипс мажор/минор: %1 / %2.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Восстановить умолчания</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Вставить символ</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Диаметр</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Дуга</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Градусы</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Плюс/Минус</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Приблизительно равно</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Асимптотически равно</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Число Пи</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Квадратный корень</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Фи</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>фи</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Альт фи</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ом</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>омега</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Умножение</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Деление</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Квадратичная</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Дельта</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>Вложенный текст</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>Измеренное значение</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Левая</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Центр</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Правая</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Выровненный</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Середина</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Заполнить</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Верх</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Основа</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Низ</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation type="unfinished">Нет</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Загрузка переводов для add-on...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Загрузка add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Инициализация add-ons...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Инициализация add-ons...</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Пост-инициализация add-ons...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Объекты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Объект</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Неизвестные объекты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Неизвестный объект</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Блоки</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Блок</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Слои</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Слой</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Тип линии</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Тип линии</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Представления</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Вид</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Сущность</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Объекты</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>3d лица</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>3d лица</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>Привязки блока</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>Привязка блока</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Привязки блока и атрибуты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Привязка блока и атрибуты</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>дуги</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Дуга</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Атрибуты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Параметр</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Определения атрибутов</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Определение атрибутов</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Окружности</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Окружность</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Размеры</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Размер</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>Выровненные размеры</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>Выровненный размер</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>Угловые размеры</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>Угловой размер</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>Диаметральные размеры</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>Диаметральный размер</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>Размеры ординаты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>Размер ординаты</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>Размеры повёрнутого</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>Размер повёрнутого</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>Радиальные размеры</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>Радиальный размер</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Эллипсы</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Эллипс</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Штриховки</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Штриховка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Изображения</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Картинка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>Полки-выноски</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>Полка-выноска</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Линии</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Линия</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Бесконечные линии</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Бесконечная линия</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Лучи</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Луч</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Точки</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Точка</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Ломаные</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Ломаная</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>Твёрдые тела</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>Сплошной</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Чертежи на кальке</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Чертёж на кальке</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Кривые</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Кривая</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Текст на основе</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Тексты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Видовые экраны</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Видовой экран</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>Неизвестные объекты</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>Неизвестный объект</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
